@@ -3,7 +3,7 @@ package Sah::Schema::unix::local_gid;
 # AUTHOR
 our $DATE = '2019-11-28'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = ["unix::gid" => {
     summary => 'Group identifier (GID) that has to exist on the system',
@@ -15,7 +15,7 @@ returns a record.
 Support coercion from an existing group name.
 
 _
-    'x.perl.coerce_rules' => ['From_str::ConvertUnixGroupToGID', 'From_int::CheckGIDExists'],
+    'x.perl.coerce_rules' => ['From_str::convert_unix_group_to_gid', 'From_int::check_gid_exists'],
 }, {}];
 
 1;
@@ -33,7 +33,7 @@ Sah::Schema::unix::local_gid - Group identifier (GID) that has to exist on the s
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::unix::local_gid (from Perl distribution Sah-Schemas-Unix), released on 2019-11-28.
+This document describes version 0.008 of Sah::Schema::unix::local_gid (from Perl distribution Sah-Schemas-Unix), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
