@@ -3,7 +3,7 @@ package Sah::Schema::unix::local_uid;
 # AUTHOR
 our $DATE = '2019-11-28'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = ["unix::uid" => {
     summary => 'User identifier (UID) that has to exist (has associated username) on the system',
@@ -15,7 +15,7 @@ returns a record.
 Support coercion from an existing user name.
 
 _
-    'x.perl.coerce_rules' => ['From_str::ConvertUnixUserToUID', 'From_int::CheckUIDExists'],
+    'x.perl.coerce_rules' => ['From_str::convert_unix_user_to_uid', 'From_int::check_uid_exists'],
 }, {}];
 
 1;
@@ -33,7 +33,7 @@ Sah::Schema::unix::local_uid - User identifier (UID) that has to exist (has asso
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::unix::local_uid (from Perl distribution Sah-Schemas-Unix), released on 2019-11-28.
+This document describes version 0.008 of Sah::Schema::unix::local_uid (from Perl distribution Sah-Schemas-Unix), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
